@@ -43,3 +43,18 @@ is.mipo <- function(x) {
 is.passive <- function(string) {
     return("~" == substring(string, 1, 1))
 }
+
+#
+# --------------------------------IS.MADS--------------------------------------
+#
+#' Check for \code{mads} object
+#' 
+#' @aliases is.mads
+#' @param x An object
+#' @return A logical indicating whether \code{x} is an object of class \code{mads}
+#' @export
+is.mads <- function(x) {
+  inherits(x, "mads")
+}
+
+
