@@ -17,7 +17,7 @@ summary.mira <- function(object, ...) {
     # This summary function is for a mira object.  Then the seperate analyses are of class lm (glm), it calls sequentially
     # summary.lm (summary.glm) for all analyses.  KO, 4/2/00
     
-    for (i in (1:length(object$analyses))) {
+    for (i in seq_along(object$analyses)) {
         cat("\n", "## summary of imputation", i, ":\n")
         print(summary(object$analyses[[i]], ...), ...)
     }
@@ -50,7 +50,7 @@ summary.mipo <- function(object, ...) {
         2 * (1 - pt(abs(table[, 3]), x$df)) else NA
     table[, 6] <- table[, 1] - qt(0.975, x$df) * table[, 2]
     table[, 7] <- table[, 1] + qt(0.975, x$df) * table[, 2]
-    if (is.null(x$nmis) | is.null(names(x$qbar)))
+    if (is.null(x$nmis) || is.null(names(x$qbar)))
         table[, 8] <- NA else table[, 8] <- x$nmis[names(x$qbar)]
     table[, 9] <- x$fmi
     table[, 10] <- x$lambda
